@@ -1,18 +1,54 @@
-#[doc = "Reader of register DORMANT_WAKE_INTE2"]
-pub type R = crate::R<u32, super::DORMANT_WAKE_INTE2>;
-#[doc = "Writer for register DORMANT_WAKE_INTE2"]
-pub type W = crate::W<u32, super::DORMANT_WAKE_INTE2>;
-#[doc = "Register DORMANT_WAKE_INTE2 `reset()`'s with value 0"]
-impl crate::ResetValue for super::DORMANT_WAKE_INTE2 {
-    type Type = u32;
+#[doc = "Register `DORMANT_WAKE_INTE2` reader"]
+pub struct R(crate::R<DORMANT_WAKE_INTE2_SPEC>);
+impl core::ops::Deref for R {
+    type Target = crate::R<DORMANT_WAKE_INTE2_SPEC>;
     #[inline(always)]
-    fn reset_value() -> Self::Type {
-        0
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
-#[doc = "Reader of field `GPIO23_EDGE_HIGH`"]
-pub type GPIO23_EDGE_HIGH_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `GPIO23_EDGE_HIGH`"]
+impl From<crate::R<DORMANT_WAKE_INTE2_SPEC>> for R {
+    #[inline(always)]
+    fn from(reader: crate::R<DORMANT_WAKE_INTE2_SPEC>) -> Self {
+        R(reader)
+    }
+}
+#[doc = "Register `DORMANT_WAKE_INTE2` writer"]
+pub struct W(crate::W<DORMANT_WAKE_INTE2_SPEC>);
+impl core::ops::Deref for W {
+    type Target = crate::W<DORMANT_WAKE_INTE2_SPEC>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+impl core::ops::DerefMut for W {
+    #[inline(always)]
+    fn deref_mut(&mut self) -> &mut Self::Target {
+        &mut self.0
+    }
+}
+impl From<crate::W<DORMANT_WAKE_INTE2_SPEC>> for W {
+    #[inline(always)]
+    fn from(writer: crate::W<DORMANT_WAKE_INTE2_SPEC>) -> Self {
+        W(writer)
+    }
+}
+#[doc = "Field `GPIO23_EDGE_HIGH` reader - "]
+pub struct GPIO23_EDGE_HIGH_R(crate::FieldReader<bool, bool>);
+impl GPIO23_EDGE_HIGH_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        GPIO23_EDGE_HIGH_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for GPIO23_EDGE_HIGH_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `GPIO23_EDGE_HIGH` writer - "]
 pub struct GPIO23_EDGE_HIGH_W<'a> {
     w: &'a mut W,
 }
@@ -30,13 +66,25 @@ impl<'a> GPIO23_EDGE_HIGH_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 31)) | (((value as u32) & 0x01) << 31);
+        self.w.bits = (self.w.bits & !(0x01 << 31)) | ((value as u32 & 0x01) << 31);
         self.w
     }
 }
-#[doc = "Reader of field `GPIO23_EDGE_LOW`"]
-pub type GPIO23_EDGE_LOW_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `GPIO23_EDGE_LOW`"]
+#[doc = "Field `GPIO23_EDGE_LOW` reader - "]
+pub struct GPIO23_EDGE_LOW_R(crate::FieldReader<bool, bool>);
+impl GPIO23_EDGE_LOW_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        GPIO23_EDGE_LOW_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for GPIO23_EDGE_LOW_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `GPIO23_EDGE_LOW` writer - "]
 pub struct GPIO23_EDGE_LOW_W<'a> {
     w: &'a mut W,
 }
@@ -54,13 +102,25 @@ impl<'a> GPIO23_EDGE_LOW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 30)) | (((value as u32) & 0x01) << 30);
+        self.w.bits = (self.w.bits & !(0x01 << 30)) | ((value as u32 & 0x01) << 30);
         self.w
     }
 }
-#[doc = "Reader of field `GPIO23_LEVEL_HIGH`"]
-pub type GPIO23_LEVEL_HIGH_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `GPIO23_LEVEL_HIGH`"]
+#[doc = "Field `GPIO23_LEVEL_HIGH` reader - "]
+pub struct GPIO23_LEVEL_HIGH_R(crate::FieldReader<bool, bool>);
+impl GPIO23_LEVEL_HIGH_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        GPIO23_LEVEL_HIGH_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for GPIO23_LEVEL_HIGH_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `GPIO23_LEVEL_HIGH` writer - "]
 pub struct GPIO23_LEVEL_HIGH_W<'a> {
     w: &'a mut W,
 }
@@ -78,13 +138,25 @@ impl<'a> GPIO23_LEVEL_HIGH_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 29)) | (((value as u32) & 0x01) << 29);
+        self.w.bits = (self.w.bits & !(0x01 << 29)) | ((value as u32 & 0x01) << 29);
         self.w
     }
 }
-#[doc = "Reader of field `GPIO23_LEVEL_LOW`"]
-pub type GPIO23_LEVEL_LOW_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `GPIO23_LEVEL_LOW`"]
+#[doc = "Field `GPIO23_LEVEL_LOW` reader - "]
+pub struct GPIO23_LEVEL_LOW_R(crate::FieldReader<bool, bool>);
+impl GPIO23_LEVEL_LOW_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        GPIO23_LEVEL_LOW_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for GPIO23_LEVEL_LOW_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `GPIO23_LEVEL_LOW` writer - "]
 pub struct GPIO23_LEVEL_LOW_W<'a> {
     w: &'a mut W,
 }
@@ -102,13 +174,25 @@ impl<'a> GPIO23_LEVEL_LOW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 28)) | (((value as u32) & 0x01) << 28);
+        self.w.bits = (self.w.bits & !(0x01 << 28)) | ((value as u32 & 0x01) << 28);
         self.w
     }
 }
-#[doc = "Reader of field `GPIO22_EDGE_HIGH`"]
-pub type GPIO22_EDGE_HIGH_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `GPIO22_EDGE_HIGH`"]
+#[doc = "Field `GPIO22_EDGE_HIGH` reader - "]
+pub struct GPIO22_EDGE_HIGH_R(crate::FieldReader<bool, bool>);
+impl GPIO22_EDGE_HIGH_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        GPIO22_EDGE_HIGH_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for GPIO22_EDGE_HIGH_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `GPIO22_EDGE_HIGH` writer - "]
 pub struct GPIO22_EDGE_HIGH_W<'a> {
     w: &'a mut W,
 }
@@ -126,13 +210,25 @@ impl<'a> GPIO22_EDGE_HIGH_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 27)) | (((value as u32) & 0x01) << 27);
+        self.w.bits = (self.w.bits & !(0x01 << 27)) | ((value as u32 & 0x01) << 27);
         self.w
     }
 }
-#[doc = "Reader of field `GPIO22_EDGE_LOW`"]
-pub type GPIO22_EDGE_LOW_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `GPIO22_EDGE_LOW`"]
+#[doc = "Field `GPIO22_EDGE_LOW` reader - "]
+pub struct GPIO22_EDGE_LOW_R(crate::FieldReader<bool, bool>);
+impl GPIO22_EDGE_LOW_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        GPIO22_EDGE_LOW_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for GPIO22_EDGE_LOW_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `GPIO22_EDGE_LOW` writer - "]
 pub struct GPIO22_EDGE_LOW_W<'a> {
     w: &'a mut W,
 }
@@ -150,13 +246,25 @@ impl<'a> GPIO22_EDGE_LOW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 26)) | (((value as u32) & 0x01) << 26);
+        self.w.bits = (self.w.bits & !(0x01 << 26)) | ((value as u32 & 0x01) << 26);
         self.w
     }
 }
-#[doc = "Reader of field `GPIO22_LEVEL_HIGH`"]
-pub type GPIO22_LEVEL_HIGH_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `GPIO22_LEVEL_HIGH`"]
+#[doc = "Field `GPIO22_LEVEL_HIGH` reader - "]
+pub struct GPIO22_LEVEL_HIGH_R(crate::FieldReader<bool, bool>);
+impl GPIO22_LEVEL_HIGH_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        GPIO22_LEVEL_HIGH_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for GPIO22_LEVEL_HIGH_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `GPIO22_LEVEL_HIGH` writer - "]
 pub struct GPIO22_LEVEL_HIGH_W<'a> {
     w: &'a mut W,
 }
@@ -174,13 +282,25 @@ impl<'a> GPIO22_LEVEL_HIGH_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 25)) | (((value as u32) & 0x01) << 25);
+        self.w.bits = (self.w.bits & !(0x01 << 25)) | ((value as u32 & 0x01) << 25);
         self.w
     }
 }
-#[doc = "Reader of field `GPIO22_LEVEL_LOW`"]
-pub type GPIO22_LEVEL_LOW_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `GPIO22_LEVEL_LOW`"]
+#[doc = "Field `GPIO22_LEVEL_LOW` reader - "]
+pub struct GPIO22_LEVEL_LOW_R(crate::FieldReader<bool, bool>);
+impl GPIO22_LEVEL_LOW_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        GPIO22_LEVEL_LOW_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for GPIO22_LEVEL_LOW_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `GPIO22_LEVEL_LOW` writer - "]
 pub struct GPIO22_LEVEL_LOW_W<'a> {
     w: &'a mut W,
 }
@@ -198,13 +318,25 @@ impl<'a> GPIO22_LEVEL_LOW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 24)) | (((value as u32) & 0x01) << 24);
+        self.w.bits = (self.w.bits & !(0x01 << 24)) | ((value as u32 & 0x01) << 24);
         self.w
     }
 }
-#[doc = "Reader of field `GPIO21_EDGE_HIGH`"]
-pub type GPIO21_EDGE_HIGH_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `GPIO21_EDGE_HIGH`"]
+#[doc = "Field `GPIO21_EDGE_HIGH` reader - "]
+pub struct GPIO21_EDGE_HIGH_R(crate::FieldReader<bool, bool>);
+impl GPIO21_EDGE_HIGH_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        GPIO21_EDGE_HIGH_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for GPIO21_EDGE_HIGH_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `GPIO21_EDGE_HIGH` writer - "]
 pub struct GPIO21_EDGE_HIGH_W<'a> {
     w: &'a mut W,
 }
@@ -222,13 +354,25 @@ impl<'a> GPIO21_EDGE_HIGH_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 23)) | (((value as u32) & 0x01) << 23);
+        self.w.bits = (self.w.bits & !(0x01 << 23)) | ((value as u32 & 0x01) << 23);
         self.w
     }
 }
-#[doc = "Reader of field `GPIO21_EDGE_LOW`"]
-pub type GPIO21_EDGE_LOW_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `GPIO21_EDGE_LOW`"]
+#[doc = "Field `GPIO21_EDGE_LOW` reader - "]
+pub struct GPIO21_EDGE_LOW_R(crate::FieldReader<bool, bool>);
+impl GPIO21_EDGE_LOW_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        GPIO21_EDGE_LOW_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for GPIO21_EDGE_LOW_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `GPIO21_EDGE_LOW` writer - "]
 pub struct GPIO21_EDGE_LOW_W<'a> {
     w: &'a mut W,
 }
@@ -246,13 +390,25 @@ impl<'a> GPIO21_EDGE_LOW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 22)) | (((value as u32) & 0x01) << 22);
+        self.w.bits = (self.w.bits & !(0x01 << 22)) | ((value as u32 & 0x01) << 22);
         self.w
     }
 }
-#[doc = "Reader of field `GPIO21_LEVEL_HIGH`"]
-pub type GPIO21_LEVEL_HIGH_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `GPIO21_LEVEL_HIGH`"]
+#[doc = "Field `GPIO21_LEVEL_HIGH` reader - "]
+pub struct GPIO21_LEVEL_HIGH_R(crate::FieldReader<bool, bool>);
+impl GPIO21_LEVEL_HIGH_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        GPIO21_LEVEL_HIGH_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for GPIO21_LEVEL_HIGH_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `GPIO21_LEVEL_HIGH` writer - "]
 pub struct GPIO21_LEVEL_HIGH_W<'a> {
     w: &'a mut W,
 }
@@ -270,13 +426,25 @@ impl<'a> GPIO21_LEVEL_HIGH_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 21)) | (((value as u32) & 0x01) << 21);
+        self.w.bits = (self.w.bits & !(0x01 << 21)) | ((value as u32 & 0x01) << 21);
         self.w
     }
 }
-#[doc = "Reader of field `GPIO21_LEVEL_LOW`"]
-pub type GPIO21_LEVEL_LOW_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `GPIO21_LEVEL_LOW`"]
+#[doc = "Field `GPIO21_LEVEL_LOW` reader - "]
+pub struct GPIO21_LEVEL_LOW_R(crate::FieldReader<bool, bool>);
+impl GPIO21_LEVEL_LOW_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        GPIO21_LEVEL_LOW_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for GPIO21_LEVEL_LOW_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `GPIO21_LEVEL_LOW` writer - "]
 pub struct GPIO21_LEVEL_LOW_W<'a> {
     w: &'a mut W,
 }
@@ -294,13 +462,25 @@ impl<'a> GPIO21_LEVEL_LOW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 20)) | (((value as u32) & 0x01) << 20);
+        self.w.bits = (self.w.bits & !(0x01 << 20)) | ((value as u32 & 0x01) << 20);
         self.w
     }
 }
-#[doc = "Reader of field `GPIO20_EDGE_HIGH`"]
-pub type GPIO20_EDGE_HIGH_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `GPIO20_EDGE_HIGH`"]
+#[doc = "Field `GPIO20_EDGE_HIGH` reader - "]
+pub struct GPIO20_EDGE_HIGH_R(crate::FieldReader<bool, bool>);
+impl GPIO20_EDGE_HIGH_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        GPIO20_EDGE_HIGH_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for GPIO20_EDGE_HIGH_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `GPIO20_EDGE_HIGH` writer - "]
 pub struct GPIO20_EDGE_HIGH_W<'a> {
     w: &'a mut W,
 }
@@ -318,13 +498,25 @@ impl<'a> GPIO20_EDGE_HIGH_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 19)) | (((value as u32) & 0x01) << 19);
+        self.w.bits = (self.w.bits & !(0x01 << 19)) | ((value as u32 & 0x01) << 19);
         self.w
     }
 }
-#[doc = "Reader of field `GPIO20_EDGE_LOW`"]
-pub type GPIO20_EDGE_LOW_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `GPIO20_EDGE_LOW`"]
+#[doc = "Field `GPIO20_EDGE_LOW` reader - "]
+pub struct GPIO20_EDGE_LOW_R(crate::FieldReader<bool, bool>);
+impl GPIO20_EDGE_LOW_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        GPIO20_EDGE_LOW_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for GPIO20_EDGE_LOW_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `GPIO20_EDGE_LOW` writer - "]
 pub struct GPIO20_EDGE_LOW_W<'a> {
     w: &'a mut W,
 }
@@ -342,13 +534,25 @@ impl<'a> GPIO20_EDGE_LOW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 18)) | (((value as u32) & 0x01) << 18);
+        self.w.bits = (self.w.bits & !(0x01 << 18)) | ((value as u32 & 0x01) << 18);
         self.w
     }
 }
-#[doc = "Reader of field `GPIO20_LEVEL_HIGH`"]
-pub type GPIO20_LEVEL_HIGH_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `GPIO20_LEVEL_HIGH`"]
+#[doc = "Field `GPIO20_LEVEL_HIGH` reader - "]
+pub struct GPIO20_LEVEL_HIGH_R(crate::FieldReader<bool, bool>);
+impl GPIO20_LEVEL_HIGH_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        GPIO20_LEVEL_HIGH_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for GPIO20_LEVEL_HIGH_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `GPIO20_LEVEL_HIGH` writer - "]
 pub struct GPIO20_LEVEL_HIGH_W<'a> {
     w: &'a mut W,
 }
@@ -366,13 +570,25 @@ impl<'a> GPIO20_LEVEL_HIGH_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 17)) | (((value as u32) & 0x01) << 17);
+        self.w.bits = (self.w.bits & !(0x01 << 17)) | ((value as u32 & 0x01) << 17);
         self.w
     }
 }
-#[doc = "Reader of field `GPIO20_LEVEL_LOW`"]
-pub type GPIO20_LEVEL_LOW_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `GPIO20_LEVEL_LOW`"]
+#[doc = "Field `GPIO20_LEVEL_LOW` reader - "]
+pub struct GPIO20_LEVEL_LOW_R(crate::FieldReader<bool, bool>);
+impl GPIO20_LEVEL_LOW_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        GPIO20_LEVEL_LOW_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for GPIO20_LEVEL_LOW_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `GPIO20_LEVEL_LOW` writer - "]
 pub struct GPIO20_LEVEL_LOW_W<'a> {
     w: &'a mut W,
 }
@@ -390,13 +606,25 @@ impl<'a> GPIO20_LEVEL_LOW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 16)) | (((value as u32) & 0x01) << 16);
+        self.w.bits = (self.w.bits & !(0x01 << 16)) | ((value as u32 & 0x01) << 16);
         self.w
     }
 }
-#[doc = "Reader of field `GPIO19_EDGE_HIGH`"]
-pub type GPIO19_EDGE_HIGH_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `GPIO19_EDGE_HIGH`"]
+#[doc = "Field `GPIO19_EDGE_HIGH` reader - "]
+pub struct GPIO19_EDGE_HIGH_R(crate::FieldReader<bool, bool>);
+impl GPIO19_EDGE_HIGH_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        GPIO19_EDGE_HIGH_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for GPIO19_EDGE_HIGH_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `GPIO19_EDGE_HIGH` writer - "]
 pub struct GPIO19_EDGE_HIGH_W<'a> {
     w: &'a mut W,
 }
@@ -414,13 +642,25 @@ impl<'a> GPIO19_EDGE_HIGH_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 15)) | (((value as u32) & 0x01) << 15);
+        self.w.bits = (self.w.bits & !(0x01 << 15)) | ((value as u32 & 0x01) << 15);
         self.w
     }
 }
-#[doc = "Reader of field `GPIO19_EDGE_LOW`"]
-pub type GPIO19_EDGE_LOW_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `GPIO19_EDGE_LOW`"]
+#[doc = "Field `GPIO19_EDGE_LOW` reader - "]
+pub struct GPIO19_EDGE_LOW_R(crate::FieldReader<bool, bool>);
+impl GPIO19_EDGE_LOW_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        GPIO19_EDGE_LOW_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for GPIO19_EDGE_LOW_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `GPIO19_EDGE_LOW` writer - "]
 pub struct GPIO19_EDGE_LOW_W<'a> {
     w: &'a mut W,
 }
@@ -438,13 +678,25 @@ impl<'a> GPIO19_EDGE_LOW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 14)) | (((value as u32) & 0x01) << 14);
+        self.w.bits = (self.w.bits & !(0x01 << 14)) | ((value as u32 & 0x01) << 14);
         self.w
     }
 }
-#[doc = "Reader of field `GPIO19_LEVEL_HIGH`"]
-pub type GPIO19_LEVEL_HIGH_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `GPIO19_LEVEL_HIGH`"]
+#[doc = "Field `GPIO19_LEVEL_HIGH` reader - "]
+pub struct GPIO19_LEVEL_HIGH_R(crate::FieldReader<bool, bool>);
+impl GPIO19_LEVEL_HIGH_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        GPIO19_LEVEL_HIGH_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for GPIO19_LEVEL_HIGH_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `GPIO19_LEVEL_HIGH` writer - "]
 pub struct GPIO19_LEVEL_HIGH_W<'a> {
     w: &'a mut W,
 }
@@ -462,13 +714,25 @@ impl<'a> GPIO19_LEVEL_HIGH_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | (((value as u32) & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
         self.w
     }
 }
-#[doc = "Reader of field `GPIO19_LEVEL_LOW`"]
-pub type GPIO19_LEVEL_LOW_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `GPIO19_LEVEL_LOW`"]
+#[doc = "Field `GPIO19_LEVEL_LOW` reader - "]
+pub struct GPIO19_LEVEL_LOW_R(crate::FieldReader<bool, bool>);
+impl GPIO19_LEVEL_LOW_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        GPIO19_LEVEL_LOW_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for GPIO19_LEVEL_LOW_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `GPIO19_LEVEL_LOW` writer - "]
 pub struct GPIO19_LEVEL_LOW_W<'a> {
     w: &'a mut W,
 }
@@ -486,13 +750,25 @@ impl<'a> GPIO19_LEVEL_LOW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | (((value as u32) & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
         self.w
     }
 }
-#[doc = "Reader of field `GPIO18_EDGE_HIGH`"]
-pub type GPIO18_EDGE_HIGH_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `GPIO18_EDGE_HIGH`"]
+#[doc = "Field `GPIO18_EDGE_HIGH` reader - "]
+pub struct GPIO18_EDGE_HIGH_R(crate::FieldReader<bool, bool>);
+impl GPIO18_EDGE_HIGH_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        GPIO18_EDGE_HIGH_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for GPIO18_EDGE_HIGH_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `GPIO18_EDGE_HIGH` writer - "]
 pub struct GPIO18_EDGE_HIGH_W<'a> {
     w: &'a mut W,
 }
@@ -510,13 +786,25 @@ impl<'a> GPIO18_EDGE_HIGH_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | (((value as u32) & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
         self.w
     }
 }
-#[doc = "Reader of field `GPIO18_EDGE_LOW`"]
-pub type GPIO18_EDGE_LOW_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `GPIO18_EDGE_LOW`"]
+#[doc = "Field `GPIO18_EDGE_LOW` reader - "]
+pub struct GPIO18_EDGE_LOW_R(crate::FieldReader<bool, bool>);
+impl GPIO18_EDGE_LOW_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        GPIO18_EDGE_LOW_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for GPIO18_EDGE_LOW_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `GPIO18_EDGE_LOW` writer - "]
 pub struct GPIO18_EDGE_LOW_W<'a> {
     w: &'a mut W,
 }
@@ -534,13 +822,25 @@ impl<'a> GPIO18_EDGE_LOW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | (((value as u32) & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
         self.w
     }
 }
-#[doc = "Reader of field `GPIO18_LEVEL_HIGH`"]
-pub type GPIO18_LEVEL_HIGH_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `GPIO18_LEVEL_HIGH`"]
+#[doc = "Field `GPIO18_LEVEL_HIGH` reader - "]
+pub struct GPIO18_LEVEL_HIGH_R(crate::FieldReader<bool, bool>);
+impl GPIO18_LEVEL_HIGH_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        GPIO18_LEVEL_HIGH_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for GPIO18_LEVEL_HIGH_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `GPIO18_LEVEL_HIGH` writer - "]
 pub struct GPIO18_LEVEL_HIGH_W<'a> {
     w: &'a mut W,
 }
@@ -558,13 +858,25 @@ impl<'a> GPIO18_LEVEL_HIGH_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | (((value as u32) & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
         self.w
     }
 }
-#[doc = "Reader of field `GPIO18_LEVEL_LOW`"]
-pub type GPIO18_LEVEL_LOW_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `GPIO18_LEVEL_LOW`"]
+#[doc = "Field `GPIO18_LEVEL_LOW` reader - "]
+pub struct GPIO18_LEVEL_LOW_R(crate::FieldReader<bool, bool>);
+impl GPIO18_LEVEL_LOW_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        GPIO18_LEVEL_LOW_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for GPIO18_LEVEL_LOW_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `GPIO18_LEVEL_LOW` writer - "]
 pub struct GPIO18_LEVEL_LOW_W<'a> {
     w: &'a mut W,
 }
@@ -582,13 +894,25 @@ impl<'a> GPIO18_LEVEL_LOW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | (((value as u32) & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
         self.w
     }
 }
-#[doc = "Reader of field `GPIO17_EDGE_HIGH`"]
-pub type GPIO17_EDGE_HIGH_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `GPIO17_EDGE_HIGH`"]
+#[doc = "Field `GPIO17_EDGE_HIGH` reader - "]
+pub struct GPIO17_EDGE_HIGH_R(crate::FieldReader<bool, bool>);
+impl GPIO17_EDGE_HIGH_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        GPIO17_EDGE_HIGH_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for GPIO17_EDGE_HIGH_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `GPIO17_EDGE_HIGH` writer - "]
 pub struct GPIO17_EDGE_HIGH_W<'a> {
     w: &'a mut W,
 }
@@ -606,13 +930,25 @@ impl<'a> GPIO17_EDGE_HIGH_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | (((value as u32) & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
         self.w
     }
 }
-#[doc = "Reader of field `GPIO17_EDGE_LOW`"]
-pub type GPIO17_EDGE_LOW_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `GPIO17_EDGE_LOW`"]
+#[doc = "Field `GPIO17_EDGE_LOW` reader - "]
+pub struct GPIO17_EDGE_LOW_R(crate::FieldReader<bool, bool>);
+impl GPIO17_EDGE_LOW_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        GPIO17_EDGE_LOW_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for GPIO17_EDGE_LOW_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `GPIO17_EDGE_LOW` writer - "]
 pub struct GPIO17_EDGE_LOW_W<'a> {
     w: &'a mut W,
 }
@@ -630,13 +966,25 @@ impl<'a> GPIO17_EDGE_LOW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | (((value as u32) & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
         self.w
     }
 }
-#[doc = "Reader of field `GPIO17_LEVEL_HIGH`"]
-pub type GPIO17_LEVEL_HIGH_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `GPIO17_LEVEL_HIGH`"]
+#[doc = "Field `GPIO17_LEVEL_HIGH` reader - "]
+pub struct GPIO17_LEVEL_HIGH_R(crate::FieldReader<bool, bool>);
+impl GPIO17_LEVEL_HIGH_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        GPIO17_LEVEL_HIGH_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for GPIO17_LEVEL_HIGH_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `GPIO17_LEVEL_HIGH` writer - "]
 pub struct GPIO17_LEVEL_HIGH_W<'a> {
     w: &'a mut W,
 }
@@ -654,13 +1002,25 @@ impl<'a> GPIO17_LEVEL_HIGH_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | (((value as u32) & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
         self.w
     }
 }
-#[doc = "Reader of field `GPIO17_LEVEL_LOW`"]
-pub type GPIO17_LEVEL_LOW_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `GPIO17_LEVEL_LOW`"]
+#[doc = "Field `GPIO17_LEVEL_LOW` reader - "]
+pub struct GPIO17_LEVEL_LOW_R(crate::FieldReader<bool, bool>);
+impl GPIO17_LEVEL_LOW_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        GPIO17_LEVEL_LOW_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for GPIO17_LEVEL_LOW_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `GPIO17_LEVEL_LOW` writer - "]
 pub struct GPIO17_LEVEL_LOW_W<'a> {
     w: &'a mut W,
 }
@@ -678,13 +1038,25 @@ impl<'a> GPIO17_LEVEL_LOW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | (((value as u32) & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
         self.w
     }
 }
-#[doc = "Reader of field `GPIO16_EDGE_HIGH`"]
-pub type GPIO16_EDGE_HIGH_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `GPIO16_EDGE_HIGH`"]
+#[doc = "Field `GPIO16_EDGE_HIGH` reader - "]
+pub struct GPIO16_EDGE_HIGH_R(crate::FieldReader<bool, bool>);
+impl GPIO16_EDGE_HIGH_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        GPIO16_EDGE_HIGH_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for GPIO16_EDGE_HIGH_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `GPIO16_EDGE_HIGH` writer - "]
 pub struct GPIO16_EDGE_HIGH_W<'a> {
     w: &'a mut W,
 }
@@ -702,13 +1074,25 @@ impl<'a> GPIO16_EDGE_HIGH_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | (((value as u32) & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
         self.w
     }
 }
-#[doc = "Reader of field `GPIO16_EDGE_LOW`"]
-pub type GPIO16_EDGE_LOW_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `GPIO16_EDGE_LOW`"]
+#[doc = "Field `GPIO16_EDGE_LOW` reader - "]
+pub struct GPIO16_EDGE_LOW_R(crate::FieldReader<bool, bool>);
+impl GPIO16_EDGE_LOW_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        GPIO16_EDGE_LOW_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for GPIO16_EDGE_LOW_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `GPIO16_EDGE_LOW` writer - "]
 pub struct GPIO16_EDGE_LOW_W<'a> {
     w: &'a mut W,
 }
@@ -726,13 +1110,25 @@ impl<'a> GPIO16_EDGE_LOW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | (((value as u32) & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
         self.w
     }
 }
-#[doc = "Reader of field `GPIO16_LEVEL_HIGH`"]
-pub type GPIO16_LEVEL_HIGH_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `GPIO16_LEVEL_HIGH`"]
+#[doc = "Field `GPIO16_LEVEL_HIGH` reader - "]
+pub struct GPIO16_LEVEL_HIGH_R(crate::FieldReader<bool, bool>);
+impl GPIO16_LEVEL_HIGH_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        GPIO16_LEVEL_HIGH_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for GPIO16_LEVEL_HIGH_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `GPIO16_LEVEL_HIGH` writer - "]
 pub struct GPIO16_LEVEL_HIGH_W<'a> {
     w: &'a mut W,
 }
@@ -750,13 +1146,25 @@ impl<'a> GPIO16_LEVEL_HIGH_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | (((value as u32) & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
         self.w
     }
 }
-#[doc = "Reader of field `GPIO16_LEVEL_LOW`"]
-pub type GPIO16_LEVEL_LOW_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `GPIO16_LEVEL_LOW`"]
+#[doc = "Field `GPIO16_LEVEL_LOW` reader - "]
+pub struct GPIO16_LEVEL_LOW_R(crate::FieldReader<bool, bool>);
+impl GPIO16_LEVEL_LOW_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        GPIO16_LEVEL_LOW_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for GPIO16_LEVEL_LOW_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `GPIO16_LEVEL_LOW` writer - "]
 pub struct GPIO16_LEVEL_LOW_W<'a> {
     w: &'a mut W,
 }
@@ -774,7 +1182,7 @@ impl<'a> GPIO16_LEVEL_LOW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | ((value as u32) & 0x01);
+        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
         self.w
     }
 }
@@ -1101,4 +1509,34 @@ impl W {
     pub fn gpio16_level_low(&mut self) -> GPIO16_LEVEL_LOW_W {
         GPIO16_LEVEL_LOW_W { w: self }
     }
+    #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
+    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
+        self.0.bits(bits);
+        self
+    }
+}
+#[doc = "Interrupt Enable for dormant_wake  
+
+This register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).  
+
+For information about available fields see [dormant_wake_inte2](index.html) module"]
+pub struct DORMANT_WAKE_INTE2_SPEC;
+impl crate::RegisterSpec for DORMANT_WAKE_INTE2_SPEC {
+    type Ux = u32;
+}
+#[doc = "`read()` method returns [dormant_wake_inte2::R](R) reader structure"]
+impl crate::Readable for DORMANT_WAKE_INTE2_SPEC {
+    type Reader = R;
+}
+#[doc = "`write(|w| ..)` method takes [dormant_wake_inte2::W](W) writer structure"]
+impl crate::Writable for DORMANT_WAKE_INTE2_SPEC {
+    type Writer = W;
+}
+#[doc = "`reset()` method sets DORMANT_WAKE_INTE2 to value 0"]
+impl crate::Resettable for DORMANT_WAKE_INTE2_SPEC {
+    #[inline(always)]
+    fn reset_value() -> Self::Ux {
+        0
+    }
 }
